Crate ibc_types_lightclients_tendermint

Crate ibc_types_lightclients_tendermint 

ICS 07: Tendermint Client implements a client verification algorithm for blockchains which use the Tendermint consensus algorithm.

Re-exports

pub use consensus_state::ConsensusState;

Modules

client_state
consensus_state
header
misbehaviour

Structs

TrustThreshold
Defines the level of trust that a client has towards a set of validators of a chain.

Enums

Error
VerificationError

Constants

TENDERMINT_CLIENT_TYPE

Functions

client_type